EXPORTS
	??0CCalTestLibrary@@IAE@H@Z @ 1 NONAME ; CCalTestLibrary::CCalTestLibrary(int)
	??1CCalTestLibrary@@UAE@XZ @ 2 NONAME ; CCalTestLibrary::~CCalTestLibrary(void)
	?CreateCalEntryL@CCalTestLibrary@@QAEPAVCCalEntry@@W4TType@2@AAPAVHBufC8@@@Z @ 3 NONAME ; class CCalEntry * CCalTestLibrary::CreateCalEntryL(enum CCalEntry::TType, class HBufC8 * &)
	?ReplaceFileL@CCalTestLibrary@@QAEXABVTDesC16@@@Z @ 4 NONAME ; void CCalTestLibrary::ReplaceFileL(class TDesC16 const &)
	?BaseConstructL@CCalTestLibrary@@IAEXXZ @ 5 NONAME ; void CCalTestLibrary::BaseConstructL(void)
	?AsynCGetInstanceViewL@CCalTestLibrary@@QAEAAVCCalInstanceView@@XZ @ 6 NONAME ; class CCalInstanceView & CCalTestLibrary::AsynCGetInstanceViewL(void)
	?NewL@CCalTestLibrary@@SAPAV1@H@Z @ 7 NONAME ; class CCalTestLibrary * CCalTestLibrary::NewL(int)
	?AsynCGetEntryViewL@CCalTestLibrary@@QAEAAVCCalEntryView@@XZ @ 8 NONAME ; class CCalEntryView & CCalTestLibrary::AsynCGetEntryViewL(void)
	?GetSession@CCalTestLibrary@@QAEAAVCCalSession@@XZ @ 9 NONAME ; class CCalSession & CCalTestLibrary::GetSession(void)
	?NewLC@CCalTestLibrary@@SAPAV1@H@Z @ 10 NONAME ; class CCalTestLibrary * CCalTestLibrary::NewLC(int)
	?CreateFileL@CCalTestLibrary@@QAEXABVTDesC16@@@Z @ 11 NONAME ; void CCalTestLibrary::CreateFileL(class TDesC16 const &)
	?RandomText8@CCalTestLibrary@@QAEXAAVTDes8@@H@Z @ 12 NONAME ; void CCalTestLibrary::RandomText8(class TDes8 &, int)
	?RandomText@CCalTestLibrary@@QAEXAAVTDes16@@H@Z @ 13 NONAME ; void CCalTestLibrary::RandomText(class TDes16 &, int)
	?SynCGetEntryViewL@CCalTestLibrary@@QAEAAVCCalEntryView@@XZ @ 14 NONAME ; class CCalEntryView & CCalTestLibrary::SynCGetEntryViewL(void)
	?SynCGetInstanceViewL@CCalTestLibrary@@QAEAAVCCalInstanceView@@XZ @ 15 NONAME ; class CCalInstanceView & CCalTestLibrary::SynCGetInstanceViewL(void)
	?DeleteFileL@CCalTestLibrary@@QAEXABVTDesC16@@H@Z @ 16 NONAME ; void CCalTestLibrary::DeleteFileL(class TDesC16 const &, int)
	?OpenFileL@CCalTestLibrary@@QAEXABVTDesC16@@H@Z @ 17 NONAME ; void CCalTestLibrary::OpenFileL(class TDesC16 const &, int)
	?SetEntryStartAndEndTimeL@CCalTestLibrary@@SAXPAVCCalEntry@@ABVTTime@@1H@Z @ 18 NONAME ; void CCalTestLibrary::SetEntryStartAndEndTimeL(class CCalEntry *, class TTime const &, class TTime const &, int)
	?FileSession@CCalTestLibrary@@QAEAAVRFs@@XZ @ 19 NONAME ; class RFs & CCalTestLibrary::FileSession(void)
	?CleanDatabaseL@CCalTestLibrary@@QAEXXZ @ 20 NONAME ; void CCalTestLibrary::CleanDatabaseL(void)
	?CreateTestFileL@CCalTestLibrary@@QAEXABVTDesC8@@ABVTDesC16@@@Z @ 21 NONAME ; void CCalTestLibrary::CreateTestFileL(class TDesC8 const &, class TDesC16 const &)
	?ExportL@CCalTestLibrary@@QAEXABVTDesC16@@AAV?$RPointerArray@VCCalEntry@@@@@Z @ 22 NONAME ; void CCalTestLibrary::ExportL(class TDesC16 const &, class RPointerArray<class CCalEntry> &)
	?FetchAllInstancesL@CCalTestLibrary@@QAEXAAV?$RPointerArray@VCCalInstance@@@@@Z @ 23 NONAME ; void CCalTestLibrary::FetchAllInstancesL(class RPointerArray<class CCalInstance> &)
	?GetIterL@CCalTestLibrary@@QAEAAVCCalIter@@XZ @ 24 NONAME ; class CCalIter & CCalTestLibrary::GetIterL(void)
	?ImportL@CCalTestLibrary@@QAEXABVTDesC16@@AAV?$RPointerArray@VCCalEntry@@@@@Z @ 25 NONAME ; void CCalTestLibrary::ImportL(class TDesC16 const &, class RPointerArray<class CCalEntry> &)
	?DataExchangeL@CCalTestLibrary@@QAEAAVCCalDataExchange@@XZ @ 26 NONAME ; class CCalDataExchange & CCalTestLibrary::DataExchangeL(void)
	?DeleteViews@CCalTestLibrary@@QAEXXZ @ 27 NONAME ; void CCalTestLibrary::DeleteViews(void)
	?ImportL@CCalTestLibrary@@QAEXABVTDesC8@@AAV?$RPointerArray@VCCalEntry@@@@@Z @ 28 NONAME ; void CCalTestLibrary::ImportL(class TDesC8 const &, class RPointerArray<class CCalEntry> &)
	?OutOfMemoryTestL@CalTestOom@@SAXAAVMCalTestOomCallBack@@W4TType@2@AAVCCalSession@@@Z @ 29 NONAME ; void CalTestOom::OutOfMemoryTestL(class MCalTestOomCallBack &, enum MCalTestOomCallBack::TType, class CCalSession &)
	?OutputInstanceDataL@CCalTestLibrary@@QAEXABV?$RPointerArray@VCCalInstance@@@@@Z @ 30 NONAME ; void CCalTestLibrary::OutputInstanceDataL(class RPointerArray<class CCalInstance> const &)
	?PIMTestServer@CCalTestLibrary@@QAEAAVRPIMTestServer@@XZ @ 31 NONAME ; class RPIMTestServer & CCalTestLibrary::PIMTestServer(void)
	?SetTimeZoneL@CCalTestLibrary@@QAEXABVTDesC8@@@Z @ 32 NONAME ; void CCalTestLibrary::SetTimeZoneL(class TDesC8 const &)
	?StoreEntryL@CCalTestLibrary@@QAEXABVCCalEntry@@@Z @ 33 NONAME ; void CCalTestLibrary::StoreEntryL(class CCalEntry const &)
	?TestRegister@CCalTestLibrary@@QAEAAVCTestRegister@@XZ @ 34 NONAME ; class CTestRegister & CCalTestLibrary::TestRegister(void)
	?StartAlarmServerL@CCalTestLibrary@@SAXXZ @ 35 NONAME ; void CCalTestLibrary::StartAlarmServerL(void)
	?CloseAgendaServer@CCalTestLibrary@@QAEXXZ @ 36 NONAME ; void CCalTestLibrary::CloseAgendaServer(void)
	?ConnectAgendaServerL@CCalTestLibrary@@QAEXXZ @ 37 NONAME ; void CCalTestLibrary::ConnectAgendaServerL(void)
	?__dbgClearTzClientCacheL@CCalTestLibrary@@QAEXH@Z @ 38 NONAME ; void CCalTestLibrary::__dbgClearTzClientCacheL(int)
	??0TPerformanceTimer@@QAE@AAVRTest@@@Z @ 39 NONAME ; TPerformanceTimer::TPerformanceTimer(class RTest &)
	?ElapsedTime@TPerformanceTimer@@QBE?AVTTimeIntervalMicroSeconds32@@XZ @ 40 NONAME ; class TTimeIntervalMicroSeconds32 TPerformanceTimer::ElapsedTime(void) const
	?PrintOut@TPerformanceTimer@@QBEXXZ @ 41 NONAME ; void TPerformanceTimer::PrintOut(void) const
	?Start@TPerformanceTimer@@QAEXXZ @ 42 NONAME ; void TPerformanceTimer::Start(void)
	?Stop@TPerformanceTimer@@QAEXXZ @ 43 NONAME ; void TPerformanceTimer::Stop(void)
	?RegisterCalFileL@CCalTestLibrary@@QAEXABVTDesC16@@@Z @ 44 NONAME ; void CCalTestLibrary::RegisterCalFileL(class TDesC16 const &)
	?WaitForAgendaServerClose@CCalTestLibrary@@SAXXZ @ 45 NONAME ; void CCalTestLibrary::WaitForAgendaServerClose(void)
	?WaitForAlarmEvent@CCalTestLibrary@@QAEHHW4TAlarmChangeEvent@@W4TAlarmState@@H@Z @ 46 NONAME ; int CCalTestLibrary::WaitForAlarmEvent(int, enum TAlarmChangeEvent, enum TAlarmState, int)

